@@ -18,6 +18,19 @@ class NestedFilesystemSerializer(WritableNestedSerializer):
         fields = ["id", "url", "display", "filesystem"]
 
 
+#
+# StorageConfiguration
+#
+class NestedStorageConfigurationSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:netbox_storage-api:storageconfiguration-detail"
+    )
+
+    class Meta:
+        model = Filesystem
+        fields = ["id", "url", "display", "virtual_machine"]
+
+
 #
 # Drive
 #
