@@ -2,11 +2,26 @@ from rest_framework import serializers
 
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
-    NestedPartitionSerializer, NestedVolumeGroupSerializer
+    NestedPartitionSerializer, NestedVolumeGroupSerializer, NestedStorageConfigurationSerializer
 from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, LogicalVolume, VolumeGroup, LinuxVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
+class StorageConfiguration(NetBoxModelSerializer):
+    # storage_configuration
+    virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
+
+    class Meta:
+        model = Drive
+        fields = (
+            "id",
+            "virtual_machine",
+            "created",
+            "last_updated",
+            "custom_fields",
+        )
+
+
 class FilesystemSerializer(serializers.ModelSerializer):
     class Meta:
         model = Filesystem
@@ -22,7 +37,7 @@ class FilesystemSerializer(serializers.ModelSerializer):
 
 class DriveSerializer(NetBoxModelSerializer):
     cluster = NestedClusterSerializer(required=False, allow_null=True)
-    virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
+    storage_configuration = NestedStorageConfigurationSerializer(required=False, allow_null=True)
     url = serializers.HyperlinkedIdentityField(view_name="plugins-api:netbox_storage-api:drive-detail")
 
     class Meta:
@@ -33,7 +48,7 @@ class DriveSerializer(NetBoxModelSerializer):
             "display",
             "size",
             "cluster",
-            "virtual_machine",
+            "storage_configuration",
             "identifier",
             "description",
             "created",
@@ -83,6 +98,7 @@ class PhysicalVolumeSerializer(serializers.ModelSerializer):
 class LogicalVolumeSerializer(serializers.ModelSerializer):
     fs = NestedFilesystemSerializer(required=False, allow_null=True)
     vg = NestedVolumeGroupSerializer(required=False, allow_null=True)
+    storage_configuration = NestedStorageConfigurationSerializer(required=False, allow_null=True)
 
     class Meta:
         model = LogicalVolume
@@ -93,6 +109,7 @@ class LogicalVolumeSerializer(serializers.ModelSerializer):
             "fs",
             "size",
             "path",
+            "storage_configuration",
             "description",
             "created",
             "last_updated",
@@ -117,6 +134,7 @@ class VolumeGroupSerializer(serializers.ModelSerializer):
 class LinuxVolumeSerializer(serializers.ModelSerializer):
     fs = NestedFilesystemSerializer(required=False, allow_null=True)
     partition = NestedPartitionSerializer(required=False, allow_null=True)
+    storage_configuration = NestedStorageConfigurationSerializer(required=False, allow_null=True)
 
     class Meta:
         model = LinuxVolume
@@ -126,6 +144,7 @@ class LinuxVolumeSerializer(serializers.ModelSerializer):
             "fs",
             "size",
             "path",
+            "storage_configuration",
             "description",
             "created",
             "last_updated",
