@@ -15,16 +15,16 @@ class DriveFilter(NetBoxModelFilterSet):
         to_field_name='name',
         label='Cluster',
     )
-    virtual_machine = django_filters.ModelMultipleChoiceFilter(
-        field_name='virtual_machine__name',
+    storage_configuration = django_filters.ModelMultipleChoiceFilter(
+        field_name='storage_configuration__name',
         queryset=VirtualMachine.objects.all(),
         to_field_name='name',
-        label='Virtual machine (name)',
+        label='storage_configuration (name)',
     )
 
     class Meta:
         model = Drive
-        fields = ("size", "cluster", "identifier", "virtual_machine", "description",)
+        fields = ("size", "cluster", "identifier", "storage_configuration", "description",)
 
     def search(self, queryset, name, value):
         """Perform the filtered search."""
