@@ -14,7 +14,8 @@ class LogicalVolumeFilter(NetBoxModelFilterSet):
             "lv_name",
             "size",
             "path",
-            "description"
+            "description",
+            "storage_configuration"
         ]
 
     def search(self, queryset, name, value):
