@@ -15,7 +15,7 @@ from utilities.forms import (
     DynamicModelChoiceField,
 )
 
-from netbox_storage.models import Drive
+from netbox_storage.models import Drive, StorageConfiguration
 from virtualization.models import Cluster, ClusterType, VirtualMachine
 
 
@@ -38,8 +38,8 @@ class DriveForm(NetBoxModelForm):
         },
         help_text="The Storage Cluster of the drive",
     )
-    virtual_machine = DynamicModelChoiceField(
-        queryset=VirtualMachine.objects.all(),
+    storage_configuration = DynamicModelChoiceField(
+        queryset=StorageConfiguration.objects.all(),
         help_text="Mapping between drive and virtual machine  e.g. vm-testinstall-01",
     )
     description = CharField(
@@ -60,7 +60,7 @@ class DriveForm(NetBoxModelForm):
             "Drive Configuration",
             (
                 "size",
-                "virtual_machine",
+                "storage_configuration",
                 "description",
             ),
         ),
@@ -72,7 +72,7 @@ class DriveForm(NetBoxModelForm):
         fields = (
             "size",
             "cluster",
-            "virtual_machine",
+            "storage_configuration",
             "description",
         )
 
@@ -92,8 +92,8 @@ class DriveFilterForm(NetBoxModelFilterSetForm):
         ),
         required=False,
     )
-    virtual_machine = DynamicModelChoiceField(
-        queryset=VirtualMachine.objects.all(),
+    storage_configuration = DynamicModelChoiceField(
+        queryset=StorageConfiguration.objects.all(),
         required=False
     )
 
@@ -105,8 +105,8 @@ class DriveImportForm(NetBoxModelImportForm):
         required=False,
         help_text='Assigned cluster'
     )
-    virtual_machine = CSVModelChoiceField(
-        queryset=VirtualMachine.objects.all(),
+    storage_configuration = CSVModelChoiceField(
+        queryset=StorageConfiguration.objects.all(),
         required=False,
         to_field_name='name',
         help_text='Required'
@@ -121,7 +121,7 @@ class DriveImportForm(NetBoxModelImportForm):
         fields = (
             "size",
             "cluster",
-            "virtual_machine",
+            "storage_configuration",
             "description",
         )
 
@@ -140,8 +140,8 @@ class DriveBulkEditForm(NetBoxModelBulkEditForm):
             'site_id': '$site'
         }
     )
-    virtual_machine = CSVModelChoiceField(
-        queryset=VirtualMachine.objects.all(),
+    storage_configuration = CSVModelChoiceField(
+        queryset=StorageConfiguration.objects.all(),
         required=False,
         to_field_name='name',
         help_text='Required'
@@ -151,7 +151,7 @@ class DriveBulkEditForm(NetBoxModelBulkEditForm):
     fieldsets = (
         (
             None,
-            ("size", "cluster", "virtual_machine", "description"),
+            ("size", "cluster", "storage_configuration", "description"),
         ),
     )
     nullable_fields = ["description"]
