@@ -16,20 +16,20 @@ from utilities.forms import (
 
 from django.urls import reverse_lazy
 
-from netbox_storage.models import Filesystem, LinuxVolume, Drive, Partition
+from netbox_storage.models import Filesystem, LinuxVolume, Drive, Partition, StorageConfiguration
 from virtualization.models import VirtualMachine
 
 
 class LinuxVolumeForm(NetBoxModelForm):
     """Form for creating a new LinuxVolume object."""
-    virtual_machine = DynamicModelChoiceField(
-        queryset=VirtualMachine.objects.all(),
+    storage_configuration = DynamicModelChoiceField(
+        queryset=StorageConfiguration.objects.all(),
         required=False,
     )
     drive = DynamicModelChoiceField(
         queryset=Drive.objects.all(),
         query_params={
-            'virtual_machine_id': '$virtual_machine',
+            'storage_configuration_id': '$storage_configuration',
         },
         help_text="The Storage Cluster of the drive",
     )
@@ -66,7 +66,7 @@ class LinuxVolumeForm(NetBoxModelForm):
         model = LinuxVolume
 
         fields = (
-            "virtual_machine",
+            "storage_configuration",
             "drive",
             "partition",
             "size",
@@ -81,13 +81,13 @@ class LinuxVolumeFilterForm(NetBoxModelFilterSetForm):
 
     model = LinuxVolume
 
-    virtual_machine = DynamicModelChoiceField(
+    storage_configuration = DynamicModelChoiceField(
         queryset=VirtualMachine.objects.all(),
     )
     drive = DynamicModelChoiceField(
         queryset=Drive.objects.all(),
         query_params={
-            'virtual_machine_id': '$virtual_machine',
+            'storage_configuration_id': '$storage_configuration',
         },
         help_text="The Storage Cluster of the drive",
     )
