@@ -16,20 +16,20 @@ from utilities.forms import (
 
 from django.urls import reverse_lazy
 
-from netbox_storage.models import Filesystem, LogicalVolume, VolumeGroup, Drive
+from netbox_storage.models import Filesystem, LogicalVolume, VolumeGroup, Drive, StorageConfiguration
 from virtualization.models import VirtualMachine
 
 
 class LogicalVolumeForm(NetBoxModelForm):
     """Form for creating a new LogicalVolume object."""
-    virtual_machine = DynamicModelChoiceField(
-        queryset=VirtualMachine.objects.all(),
+    storage_configuration = DynamicModelChoiceField(
+        queryset=StorageConfiguration.objects.all(),
         required=False,
     )
     drive = DynamicModelChoiceField(
         queryset=Drive.objects.all(),
         query_params={
-            'virtual_machine_id': '$virtual_machine',
+            'storage_configuration_id': 'storage_configuration',
         },
         help_text="The Storage Cluster of the drive",
     )
@@ -67,7 +67,7 @@ class LogicalVolumeForm(NetBoxModelForm):
         model = LogicalVolume
 
         fields = (
-            "virtual_machine",
+            "storage_configuration",
             "drive",
             "vg",
             "lv_name",
