@@ -16,7 +16,8 @@ from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
 
-from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume
+from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume, \
+    StorageConfiguration
 from virtualization.models import Cluster, ClusterType, VirtualMachine
 import logging
 
@@ -93,73 +94,79 @@ class LVMSimpleForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = Drive
+        model = StorageConfiguration
         exclude = (
-                    "cluster_type",
-                    "vg_name",
-                    "path",
-                    "fs",
-                    "description",
+            "cluster_type",
+            "vg_name",
+            "path",
+            "fs",
+            "description",
+            "cluster",
+            "size",
         )
         fields = [
-            "cluster",
             "virtual_machine",
-            "size",
         ]
 
     def save(self, *args, **kwargs):
-        drive = super().save(*args, **kwargs)
-        logger = logging.getLogger('netbox.plugins.netbox_storage')
+        storage_configuration = super().save(*args, **kwargs)
 
-        logger.warning(f'{self.instance}')
-        logger.warning(f'{self.instance.lv_name}')
-        logger.warning(f'{self.instance.vg_name}')
-        logger.warning(f'{self.instance.path}')
-        logger.warning(f'{self.instance.fs}')
-        logger.warning(f'{self.instance.size}')
-        logger.warning(f'{self.instance.virtual_machine}')
+        drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'],
+                                     storage_configuration=storage_configuration)
+        partition = Partition.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'],
+                                             type='Linux LVM', description='Partition 1 on SSD Cluster')
+        volumegroup = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
+        physicalvolume = PhysicalVolume.objects.create(partition=partition, pv_name=drive.device_name(), vg=volumegroup)
+        logicalvolume = LogicalVolume.objects.create(vg=volumegroup,
+                                                     lv_name=self.cleaned_data['lv_name'],
+                                                     size=self.cleaned_data['size'],
+                                                     path=self.cleaned_data['path'],
+                                                     fs=self.cleaned_data['fs'],
+                                                     storage_configuration=self.cleaned_data['storage_configuration'])
+        print(f"{self.cleaned_data['lv_name']}")
+        print(f"{self.cleaned_data['vg_name']}")
+        print(f"{self.cleaned_data['size']}")
+        print(f"{self.cleaned_data['path']}")
+        print(f"{self.cleaned_data['fs']}")
 
-        # logger.warning(f'--------- Instance: {instance}')
-        # logger.warning(f'--------- Instance: {instance.pk}')
-        # partition = Partition(drive=instance, device=instance.device_name, size=instance.size, type="Linux LVM")
-        # partition.save()
-        # logger.warning(f'{partition}')
-        # vg = VolumeGroup(vg_name=self.vg_name)
-        # vg.save()
-        # logger.warning(f'{vg}')
-        # physicalvolume = PhysicalVolume(partition=partition, pv_name=instance.device_name, vg=vg)
-        """physicalvolume.save()
-        logger.warning(f'{physicalvolume}')
-        logicalvolume = LogicalVolume(vg=vg, size=self.size, path=self.path, fs=self.fs)
-        logger.warning(f'{logicalvolume}')
-        logicalvolume.save()"""
+        print("Instances")
+        print(drive)
+        print(partition)
+        print(volumegroup)
+        print(physicalvolume)
+        print(logicalvolume)
 
         return drive
 
 
-class LVSimpleForm(NetBoxModelForm):
+class VolumeSimpleForm(NetBoxModelForm):
     """Form for creating a new Drive object."""
     # ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
     size = FloatField(
         label="Size (GB)",
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
+        required=False
     )
     lv_name = CharField(
         label="LV Name",
         help_text="The logical volume name e.g. lv_data",
+        required=False
     )
     vg_name = CharField(
         label="VG Name",
         help_text="The volume group name e.g. vg_data",
+        required=False
     )
     path = CharField(
         label="Path",
         help_text="The mounted path of the volume e.g. /var/lib/docker",
+        required=False
     )
     hard_drive_label = CharField(
         label="Hard Drive Label",
         help_text="The label of the hard drive e.g. D",
+        required=False
     )
     fs = DynamicModelChoiceField(
         queryset=Filesystem.objects.all(),
@@ -168,6 +175,7 @@ class LVSimpleForm(NetBoxModelForm):
             attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:filesystem-list")}
         ),
         help_text="The Filesystem of the Volume e.g. ext4",
+        required=False
     )
     cluster_type = DynamicModelChoiceField(
         queryset=ClusterType.objects.all(),
@@ -180,8 +188,8 @@ class LVSimpleForm(NetBoxModelForm):
         },
         help_text="The Storage Cluster of the drive",
     )
-    virtual_machine = DynamicModelChoiceField(
-        queryset=VirtualMachine.objects.all(),
+    storage_configuration = DynamicModelChoiceField(
+        queryset=StorageConfiguration.objects.all(),
         help_text="Mapping between drive and virtual machine  e.g. vm-testinstall-01",
     )
     description = CharField(
@@ -196,7 +204,7 @@ class LVSimpleForm(NetBoxModelForm):
         fields = (
             "size",
             "cluster",
-            "virtual_machine",
+            "storage_configuration",
             "description",
         )
 
@@ -204,11 +212,11 @@ class LVSimpleForm(NetBoxModelForm):
         drive = super().save(*args, **kwargs)
 
         # Assign/clear this IPAddress as the primary for the associated Device/VirtualMachine.
-        if self.instance.vg_name is not None:
-            print(f"{self.instance.vg_name}")
-        elif self.instance.lv_name is not None:
-            print(f"{self.instance.size}")
-        else:
-            print(f"{self.instance.hard_drive_label}")
+        # print(f"{self.instance}")
+        print(f"{self.cleaned_data['lv_data']}")
+        print(f"{self.cleaned_data['vg_data']}")
+        print(f"{self.cleaned_data['size']}")
+        print(f"{self.cleaned_data['path']}")
+        print(f"{self.cleaned_data['fs']}")
 
         return drive
