@@ -6,6 +6,26 @@ class Migration(migrations.Migration):
     initial = True
 
     operations = [
+        migrations.CreateModel(
+            name="StorageConfiguration",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("virtual_machine",
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
+                                   related_name="virtual_machine_storage_configuration",
+                                   to="virtualization.virtualmachine")),
+            ],
+        ),
         migrations.CreateModel(
             name="Drive",
             fields=[
@@ -23,9 +43,10 @@ class Migration(migrations.Migration):
                 ("cluster",
                  models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="cluster_drive",
                                    to="virtualization.cluster")),
-                ("virtual_machine",
+                ("storage_configuration",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
-                                   related_name="virtual_machine_drive", to="virtualization.virtualmachine")),
+                                   related_name="storage_configuration_drive",
+                                   to="netbox_storage.storageconfiguration")),
                 ("size", models.FloatField()),
                 ("identifier", models.CharField(max_length=255)),
                 ("description", models.CharField(max_length=255)),
@@ -153,6 +174,10 @@ class Migration(migrations.Migration):
                                    to='netbox_storage.filesystem')),
                 ("size", models.FloatField()),
                 ("description", models.CharField(max_length=255)),
+                ("storage_configuration",
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
+                                   related_name="storage_configuration_logical_volume",
+                                   to="netbox_storage.storageconfiguration")),
             ],
             options={
                 "ordering": ("lv_name", "id"),
@@ -181,6 +206,10 @@ class Migration(migrations.Migration):
                                    to='netbox_storage.filesystem')),
                 ("size", models.FloatField()),
                 ("description", models.CharField(max_length=255)),
+                ("storage_configuration",
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
+                                   related_name="storage_configuration_linux_volume",
+                                   to="netbox_storage.storageconfiguration")),
             ],
             options={
                 "ordering": ("path", "fs", "id"),
