@@ -3,20 +3,34 @@ from django.db import models
 from django.db.models import Sum
 from django.urls import reverse
 
+from dcim.models import Platform
 from netbox.models import NetBoxModel
 
 
+class StorageConfiguration(NetBoxModel):
+    virtual_machine = models.ForeignKey(
+        to='virtualization.VirtualMachine',
+        on_delete=models.CASCADE,
+        related_name='virtual_machine_storage_configuration',
+    )
+
+    clone_fields = [
+        "virtual_machine"
+    ]
+
+    def get_absolute_url(self):
+        return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
+
+    def __str__(self):
+        return f"Storage Configuration of the VM {self.virtual_machine}"
+
+
 class Drive(NetBoxModel):
     cluster = models.ForeignKey(
         to='virtualization.Cluster',
         on_delete=models.PROTECT,
         related_name='cluster_drive',
     )
-    virtual_machine = models.ForeignKey(
-        to='virtualization.VirtualMachine',
-        on_delete=models.CASCADE,
-        related_name='virtual_machine_drive',
-    )
     size = models.FloatField(
         verbose_name="Size (GB)"
     )
@@ -27,8 +41,13 @@ class Drive(NetBoxModel):
         max_length=255,
         blank=True,
     )
+    storage_configuration = models.ForeignKey(
+        StorageConfiguration,
+        on_delete=models.CASCADE,
+        related_name='storage_configuration_linux_volume',
+    )
 
-    clone_fields = ["cluster", "virtual_machine", "size", "identifier", "description"]
+    clone_fields = ["cluster", "size", "identifier", "description", "storage_configuration"]
 
     prerequisite_models = (
         'virtualization.Cluster',
@@ -39,7 +58,7 @@ class Drive(NetBoxModel):
         ordering = ["size"]
 
     def __str__(self):
-        return f"VM: {self.virtual_machine} ({self.identifier}-{self.size}GB-{self.cluster})"
+        return f"VM: ({self.identifier}-{self.size}GB-{self.cluster})"
 
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:drive", kwargs={"pk": self.pk})
@@ -47,8 +66,8 @@ class Drive(NetBoxModel):
     def save(self, *args, **kwargs):
         is_already_implemented = Drive.objects.filter(id=self.pk).count()
         if is_already_implemented == 0:
-            number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created") \
-                .count()
+            number_of_hard_drives = Drive.objects.filter(storage_configuration=self.storage_configuration).\
+                order_by("created").count()
 
             self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
 
@@ -270,6 +289,11 @@ class LogicalVolume(NetBoxModel):
         max_length=255,
         blank=True,
     )
+    storage_configuration = models.ForeignKey(
+        StorageConfiguration,
+        on_delete=models.CASCADE,
+        related_name='storage_configuration_logical_volume',
+    )
 
     clone_fields = [
         "vg",
@@ -278,6 +302,7 @@ class LogicalVolume(NetBoxModel):
         "path",
         "fs",
         "description",
+        "storage_configuration"
     ]
 
     #prerequisite_models = (
@@ -319,6 +344,11 @@ class LinuxVolume(NetBoxModel):
         max_length=255,
         blank=True,
     )
+    storage_configuration = models.ForeignKey(
+        StorageConfiguration,
+        on_delete=models.CASCADE,
+        related_name='storage_configuration_linux_volume',
+    )
 
     clone_fields = [
         "partition",
@@ -326,14 +356,9 @@ class LinuxVolume(NetBoxModel):
         "path",
         "fs",
         "description",
+        "storage_configuration"
     ]
 
-    #prerequisite_models = (
-    #    'netbox_storage.Filesystem',
-    #    'netbox_storage.Drive',
-    #    'netbox_storage.Partition',
-    #)
-
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
 
