@@ -12,7 +12,7 @@ class DriveTable(NetBoxTable):
     """Table for displaying Drives objects."""
 
     pk = ToggleColumn()
-    virtual_machine = tables.Column(
+    storage_configuration = tables.Column(
         linkify=True
     )
     identifier = tables.Column(
@@ -32,11 +32,11 @@ class DriveTable(NetBoxTable):
             "size",
             "cluster",
             "identifier",
-            "virtual_machine",
+            "storage_configuration",
             "description",
         )
         default_columns = (
-            "virtual_machine",
+            "storage_configuration",
             "identifier",
             "size",
             "cluster",
