@@ -20,7 +20,7 @@ class LVMModel:
 class RelatedDrives(PluginTemplateExtension):
     model = "virtualization.virtualmachine"
 
-    def full_width_page(self):
+    def left_page(self):
         obj = self.context.get("object")
 
         # --- Try via Logical Volume
@@ -57,55 +57,7 @@ class RelatedDrives(PluginTemplateExtension):
         linux_volume_list = list(LinuxVolume.objects.all())
         logger.warning(f'linuxvolumes for {linux_volume_list}')
 
-        # drives = Drive.objects.filter(
-        #     virtual_machine=obj
-        # )
-        # drive_table = RelatedDriveTable(
-        #     data=drives
-        # )
-        # volumes = LinuxVolume.objects.all()
-        # exclude_drive_id = []
-        # for inc in volumes.all():
-        #     for drive in inc.drives.all():
-        #         exclude_drive_id.append(drive.id)
-        # unmapped_drives = Drive.objects.filter(
-        #     virtual_machine=obj
-        # ).exclude(id__in=exclude_drive_id).order_by('identifier')
-
-        # all_volumes = LinuxVolume.objects.all()
-        # display_volume = []
-        # for inc in all_volumes:
-        #     display_volume = inc.drives.all().intersection(drives)
-
-
-        #partitions = []
-        #for drive in drives:
-        #    partitions = Partition.objects.filter(
-        #        drive=drive
-        #    )
-
-        # hd_partition_list = []
-        # for drive in drives:
-        #     hd_partition = [drive]
-        #     partitions = Partition.objects.filter(
-        #         drive=drive
-        #     ).values_list()
-        #     hd_partition.append(partitions)
-        #     hd_partition_list.append(hd_partition)
-
-        #physical_volumes = PhysicalVolume.objects.filter(
-        #    partition__in=partitions
-        #)
-
-        #volume_group_list = physical_volumes.values_list('vg', flat=True)
-
-        #logical_volumes = LogicalVolume.objects.filter(
-        #    vg__in=volume_group_list
-        #)
-
-        # result_list = list(chain(drives, partitions, volume_group_list, logical_volumes))
-        # logger.warning(f'{result_list}')
-
+        lv = LogicalVolume.objects.filter(storage_configuration=obj)
 
         platform = obj.platform
         if platform is not None:
@@ -134,6 +86,9 @@ class RelatedDrives(PluginTemplateExtension):
         else:
             return self.render(
                 "netbox_storage/inc/unknown_os_box.html",
+                extra_context={
+                    "lv": lv
+                }
             )
 
 
