@@ -60,8 +60,11 @@ from netbox_storage.views import (
     LinuxVolumeBulkEditView,
     LinuxVolumeBulkDeleteView,
     LinuxVolumeView,
-    LinuxVolumeDeleteView, VolumeGroupPhysicalVolumeListView, VolumeGroupLogicalVolumeListView, LVMAddSimpleView,
-    LVAddSimpleView, AddVolume,
+    LinuxVolumeDeleteView,
+    VolumeGroupPhysicalVolumeListView,
+    VolumeGroupLogicalVolumeListView,
+    LVMAddSimpleView,
+    AddVolume,
 )
 
 app_name = "netbox_storage"
@@ -194,7 +197,6 @@ urlpatterns = [
     #
     # Simple Configuration
     #
-    path("lvm-simple/add/", LVMAddSimpleView.as_view(), name="lvm_simple_add"),
-    path("lv-simple/add/", LVAddSimpleView.as_view(), name="lv_simple_add"),
-    path('lv-add/', AddVolume.as_view(), name="lv_volume_add")
+    path('lvm-add/', LVMAddSimpleView.as_view(), name='lvm_add'),
+    path('volume-add/', AddVolume.as_view(), name="volume_add")
 ]
