@@ -1,6 +1,6 @@
 from netbox.views import generic
 
-from netbox_storage.forms import LVSimpleForm, LVMSimpleForm
+from netbox_storage.forms import LVMSimpleForm, VolumeSimpleForm
 from netbox_storage.models import LinuxVolume, LogicalVolume, Drive
 
 
@@ -12,17 +12,18 @@ class LVMAddSimpleView(generic.ObjectEditView):
     default_return_url = "plugins:netbox_storage:drive_list"
 
 
-class LVAddSimpleView(generic.ObjectEditView):
+# class LVAddSimpleView(generic.ObjectEditView):
     """View for editing a Drive instance."""
 
-    queryset = LinuxVolume.objects.all()
-    form = LVSimpleForm
-    default_return_url = "plugins:netbox_storage:drive_list"
+#    queryset = LinuxVolume.objects.all()
+#    form = LVSimpleForm
+#    default_return_url = "plugins:netbox_storage:drive_list"
 
 
 class AddVolume(generic.ObjectEditView):
     """View for editing a Drive instance."""
     template_name = "netbox_storage/inc/volume_add.html"
     queryset = Drive.objects.all()
-    form = LVSimpleForm
+    form = VolumeSimpleForm
     default_return_url = "plugins:netbox_storage:drive_list"
+    # default_return_url = "virtualization:virtualmachine"
